//
//  ViewController.m
//  sculpteoUploadExample
//
//  Created by Vivien Chappelier on 30/03/12.
//  Copyright (c) 2012 Sculpteo. All rights reserved.
//

#import "ViewController.h"
#import "ASIFormDataRequest.h"
#import "NSString+UUID.h"

#define SCULPTEO_SITE @"m.sculpteo.com"
#define FILE_UPLOAD_URL @"/en/upload/file/"
#define DESIGN_UPLOAD_FORM_URL @"/en/upload_design/a/3D/"

@interface ViewController () {
    UIProgressView *progressBar;
    UIButton *printButton;
    ASIFormDataRequest *uploadRequest;
    NSString *uploadUuid;
}
@end

@implementation ViewController

- (void)uploadCompleteAction
{
    NSString *name = @"Scupteo Upload Example Design";
    
    // redirect to Sculpteo website to proceed
    NSString *designUploadFormUrl =
        [NSString stringWithFormat:@"http://%@%@?X-Progress-ID=%@&name=%@&click=cart&unit=cm&scale=1.0",
         SCULPTEO_SITE, DESIGN_UPLOAD_FORM_URL, uploadUuid,
         [name stringByAddingPercentEscapesUsingEncoding:NSUTF8StringEncoding]];
    NSURL *url = [NSURL URLWithString:designUploadFormUrl];
    
    // open in Safari, could use UIWebView as well
    [[UIApplication sharedApplication] openURL:url];
}

// ASIHttpRequest procotol
- (void)requestFailed:(ASIFormDataRequest *)request
{
    NSError *error = [request error];
    NSLog(@"Upload failed: %@", [error description]);
    
    UIAlertView *alertView = [[UIAlertView alloc] initWithTitle:@"Upload error" message:[error localizedDescription] delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil];
    [alertView show];
    [progressBar setHidden:YES];
    
    uploadRequest = nil;
}

- (void)requestFinished:(ASIFormDataRequest *)request
{
    // check for server error
    NSString *responseString = [request responseString];
    NSInteger statusCode = [request responseStatusCode];
    if (statusCode >= 400) {
        NSLog(@"Request finished with error %d:\n %@", statusCode, responseString);
        request.error = [NSError errorWithDomain:@"HTTP" code:statusCode userInfo:[NSDictionary dictionaryWithObjectsAndKeys: responseString, NSLocalizedDescriptionKey, nil]];
        [self requestFailed:request];
        return;
    }
    
    uploadRequest = nil;
    [progressBar setHidden:YES];

    [self uploadCompleteAction];
}

- (void)printButtonAction:(id)sender
{    
    // load the data from bundle file 'example.obj'
    NSBundle *mainBundle = [NSBundle mainBundle];
    NSString *filePath = [mainBundle pathForResource:@"example" ofType:@"zip"];
    NSData *data = [NSData dataWithContentsOfFile:filePath];
    
    // generate unique identifier for the upload request
    NSString *uuid = [NSString UUID];
    uploadUuid = uuid;
    
    // choose a filename and mime type for the uploaded file
    // please use a consistent extension here
    NSString *filename = @"example.zip";
    NSString *mimetype = @"application/zip";
    
    // build url to POST the 3D file
    NSString *uploadUrl = [NSString stringWithFormat:@"http://%@%@?X-Progress-ID=%@", SCULPTEO_SITE, FILE_UPLOAD_URL, uuid];
    NSURL *url = [NSURL URLWithString:uploadUrl];
    
    // show the progress bar
    [progressBar setProgress:0];
    [progressBar setHidden:NO];
    
    // use ASIFormDataRequest to upload the file asynchronously with progress indication
    uploadRequest = [ASIFormDataRequest requestWithURL:url];
    [uploadRequest setData:data withFileName:filename andContentType:mimetype forKey:@"file"];
    [uploadRequest setDelegate:self];
    [uploadRequest setUploadProgressDelegate:progressBar];
    [uploadRequest startAsynchronous];
}

- (void)dealloc
{
    // abort asynchronous request
    [uploadRequest clearDelegatesAndCancel];
}

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
    progressBar = (UIProgressView *)[self.view viewWithTag:1];
    printButton = (UIButton *)[self.view viewWithTag:2];
    [printButton addTarget:self action:@selector(printButtonAction:) forControlEvents:UIControlEventTouchUpInside];
    [progressBar setHidden:YES];
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    progressBar = nil;
    printButton = nil;
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    if ([[UIDevice currentDevice] userInterfaceIdiom] == UIUserInterfaceIdiomPhone) {
        return (interfaceOrientation != UIInterfaceOrientationPortraitUpsideDown);
    } else {
        return YES;
    }
}

@end
